pub enum Error {
IoError(Error),
DecodeError(&'static str),
SeekError(SeekErrorKind),
Unsupported(&'static str),
LimitError(&'static str),
ResetRequired,
}Expand description
Error provides an enumeration of all possible errors reported by Symphonia.
Variants
IoError(Error)
An IO error occured while reading, writing, or seeking the stream.
DecodeError(&'static str)
The stream contained malformed data and could not be decoded or demuxed.
SeekError(SeekErrorKind)
The stream could not be seeked.
Unsupported(&'static str)
An unsupported container or codec feature was encounted.
LimitError(&'static str)
A default or user-defined limit was reached while decoding or demuxing the stream. Limits are used to prevent denial-of-service attacks from malicious streams.
ResetRequired
The demuxer or decoder needs to be reset before continuing.